/*
A simple adaptation of the preprocessor file
J. Hearon 9/1/2011
*/

#include "cscore.h"                                /*  CSCORE.C */

void cscore2(CSOUND *cs, float *p3array, int *p4array, int numspitches, int numsrhys)  /* callable from Csound or standalone cscore  */
                         /* csound -C will run Csound scores as normal */
{
      EVENT  *e, *f, *g, *h, *i, *j;
      EVLIST *a, *b;
      int n;
      float sum = 0.0;

      int *s = p4array; //midi pitch nums
      float *t = p3array; //durations as float values

        int wavenum = 2; //sawtooth

        // f1, creates f-statement for one period of a SINE wave
        e = cscoreCreateEvent(cs,5);            /* alloc p0-5 and init pcnt */
        e->op = 'f';
        e->p[1] = 1;
        e->p[2] = 0;
        e->p[3] = 8192;
        e->p[4] = 10;
        e->p[5] = 1;
        cscorePutEvent(cs,e);                   // write it out
        cscoreFreeEvent(cs,e);                  // free memory

        // f2, creates f-statement for one period of an approx SAWTOOTH wave
        f = cscoreCreateEvent(cs,14);            /* alloc p0-14 and init pcnt */
        f->op = 'f';
        f->p[1] = 2;
        f->p[2] = 0;
        f->p[3] = 8192;
        f->p[4] = 10;
        f->p[5] = 1;
        f->p[6] = 0.5;
        f->p[7] = 0.333;
        f->p[8] = 0.25;
        f->p[9] = 0.2;
        f->p[10] = 0.1667;
        f->p[11] = 0.1429;
        f->p[12] = 0.125;
        f->p[13] = 0.111;
        f->p[14] = 0.1;
        cscorePutEvent(cs,f);                   //write it out
        cscoreFreeEvent(cs,f);                  //free memory

        // f3, creates f-statement for one period of an approx SQUARE wave
        g = cscoreCreateEvent(cs,14);            /* alloc p0-14 and init pcnt */
        g->op = 'f';
        g->p[1] = 3;
        g->p[2] = 0;
        g->p[3] = 8192;
        g->p[4] = 10;
        g->p[5] = 1;
        g->p[6] = 0.0;
        g->p[7] = 0.333;
        g->p[8] = 0.0;
        g->p[9] = 0.2;
        g->p[10] = 0.0;
        g->p[11] = 0.1429;
        g->p[12] = 0.0;
        g->p[13] = 0.111;
        g->p[14] = 0.0;
        cscorePutEvent(cs,g);                   //write it out
        cscoreFreeEvent(cs,g);                  //free memory

        // f4, creates f-statement for one period of an approx TRAIANGLE wave
        h = cscoreCreateEvent(cs,17);            /* alloc p0-14 and init pcnt */
        h->op = 'f';
        h->p[1] = 4;
        h->p[2] = 0;
        h->p[3] = 8192;
        h->p[4] = 10;
        h->p[5] = 1;
        h->p[6] = 0.0;
        h->p[7] = -0.111;
        h->p[8] = 0.0;
        h->p[9] = 0.04;
        h->p[10] = 0.0;
        h->p[11] = -0.0204;
        h->p[12] = 0.0;
        h->p[13] = 0.0123;
        h->p[14] = 0.0;
        h->p[15] = -0.0083;
        h->p[16] = 0.0;
        h->p[17] = 0.0059;
        cscorePutEvent(cs,h);                   //write it out
        cscoreFreeEvent(cs,h);                  //free memory

        //TEMPO statement
        i = cscoreCreateEvent(cs, 2);
        i->op = 't';
        i->p[1] = 0;
        i->p[2] = 60;
        cscorePutEvent(cs,i);                   //write it out
        cscoreFreeEvent(cs,i);                  //free memory

      for (n = 1; n < numspitches; n++)        /* iterate the following lines nevents times: */
      {
            j = cscoreCreateEvent(cs, 5); /* allocate a note with 5 pfields */
            j->op = 'i';
            j->p[1] = 1;                  /* instrument 1 */
            sum = sum + t[n-1];
            j->p[2] = sum;/* start time */
            j->p[3] = t[n];

            j->p[4] = s[n];                /* midi pitch num */
            j->p[5] = wavenum;              /* f-statement or waveform */
      cscorePutEvent(cs,j);
      }

      cscorePutString(cs, "s");
      cscorePutString(cs, "e");  //writes to outsco

      cscoreFreeEvent(cs,j);
      return;
}
